GOOF----LE-8-2.0 I      ] l 4  h@      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  BASE-VAL	g  stock	g  waste					 	g  
foundation							
		 	g  tableau		
						 	g  reserve	g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-blank-slot	g  add-carriage-return-slot	g  add-extended-slot	g  down	 g  HORIZPOS	!g  VERTPOS	"e  0.5	#g  
deal-cards	$					
						
					
			
					 	%g  deal-cards-face-up	&						
			
							 	'g  
add-to-score!	(g  	get-value	)g  get-top-card	*g  give-status-message	+g  new-game	,g  set-statusbar-message	-g  
string-append	.g  get-stock-no-string	/f     	0g  get-base-string	1g  _	2f  Base Card: Ace	3f  Base Card: Jack	4f  Base Card: Queen	5f  Base Card: King	6f   	7f  
Base Card:	8f   	9g  number->string	:g  length	;g  	get-cards	<f  Stock left:	=f  
Stock left: 0	>g  empty-slot?	?g  is-visible?	@g  reverse	Ag  button-pressed	Bg  get-suit	Cg  king	Dg  ace	Eg  to-foundation?	Fg  is-red?	Gg  to-tableau?	Hg  
droppable?	Ig  make-visible-top-card	Jg  
move-n-cards!	Kg  button-released	L 	Mg  button-clicked	Ng  	add-card!	Og  move-to-foundations?	Pg  remove-card	Qg  button-double-clicked	Rg  game-won	Sg  get-hint	Tg  game-continuable	Uf  Deal another round	Vg  	dealable?	Wg  	hint-move	Xg  check-a-foundation	Yg  check-to-foundations	Zg  check-a-foundation2	[g  stripped	\g  check-a-tableau-with-pile	]g  	is-black?	^g  check-a-tableau	_g  check-to-tableau?	`g  get-top-visible-card	ag  visible-card-count	bg  find-high-value	cg  find-empty-slot	dg  empty-tableau?	ef  Try rearranging the cards	fg  get-options	gg  
apply-options	hg  timeout	ig  set-features	jg  droppable-feature	kg  
set-lambdaC 5   h>    ] 4	 >  "  G  

R
RRRRR !"#$%&'()
*  h8    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4	>   "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4>   "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  
 
  	 4>  "  G  4>   "  G  	 4>  "  G  4>   "  G  	 4>  "  G  4>   "  G  	 
 
 	 4	>   "  G  4>  "  G  4>   "  G  	 4	>   "  G  4>  "  G  4>   "  G  	 4	>   "  G  4>  "  G  4>   "  G  	 4	>   "  G  4>  "  G  4
>  "  G  4
>  "  G  4>  "  G  44	55 4>   "  G  			 C         g  filenamef  
lady-jane.scm
	
							#			3			C	 		I	 		N	 		W	!		Z	!		\	!		a	!		j	#		z	%		}	%			%	 	%	 	&	 	&	 	&	 	&	 	'	 	'	 	'	 	'	 	(	 	(	 	(	 	(	 	*	 	,	 	,	 	,	 	,	 	-	 	-	 	-	 	-	 	.		.		.		.		/		/		/	!	/	*	0	-	0	1	0	6	0	?	1	B	1	F	1	K	1	T	2	W	2	[	2	`	2	k	4	n	5	r	7	s	7	u	7	z	8	|	8	}	9		9		9		9		:		;		;		<		<		<		<		=		>		>		?		?		?		?		@		A		A		D	 	E		G		G		H		I		I		I	"	I	+	J	?	K	A	K	B	L	R	M	U	M	W	M	\	M	e	N	y	O	{	O	|	P		Q		Q		Q		Q		R		S		S		T		U		U		U		U		W		W		W		Y		Y		Y		[		]		]		]		]		_	4	a	 	5
  g  nameg  new-game C+R,-./0      h      ] 445 45 56        g  filenamef  
lady-jane.scm
	d
		e			e	(		f	(		g	(		e			e	 		
  g  nameg  give-status-message C*R
123456-789    hx   ;  ] "  >$  6	$  6	$  6	
$  6C$  !	$  4	5
456""       3      g  filenamef  
lady-jane.scm
	i
	
	m				j			n			n				o				j		!	p		#	p			(	q			,	j		0	r		2	r			7	s			;	j		?	t		A	t			C	u		D	j		H	j		L	j		Q	k		U	j			X	l		\	l		^	l		`	l	(	a	l	,	i	l		 		q
  g  nameg  get-base-string C0R:;-1<89= 	     h@      ] 44
55$  45444
5556456            g  filenamef  
lady-jane.scm
	w
		x				x		
	x				x			x			y			y			y			y	&		z		"	z	%	%	z	-	,	z	%	.	z		0	y		3	{		7	{		9	{		;	{	 		;
  g  nameg  get-stock-no-string C.R>?@    h       ]4 5$  C456            g  slot-id
		 g  	card-list		  g  filenamef  
lady-jane.scm
	}
		~		
	~										 			  g  nameg  button-pressed CAR>(
B)CD    hx   b  ]
45$  4 5C4 54455&  @44554 5$  C4455$  4 5CCC       Z      g  card
		q g  end-slot		q g  t		D	o  g  filenamef  
lady-jane.scm
 
	 		
 		 			 		 		  		# 		+ 		/ 		0 		3 	"	; 		< 		= 		D 		D 		P 		S 	"	[ 		^ 		b 		c 		l 	 		q	  g  nameg  to-foundation? CER>(
DCF) h     ]
45$  ,4 5$  C$  4 5CC4 54455&  C4455$  C44554 5$  C4455$  4 5CC       g  card
	  g  end-slot	  g  t			9 g  t		|   g  filenamef  
lady-jane.scm
 
	 		
 		 	
	 		 	
	 		( 		, 	
	- 		6 		: 		A 		D 		L 		P 		S 		V 		^ 		a 		e 		h 		k 		s 		t 		{ 		| 		| 	  	  	"  	  	  	  	  	 $	 	  g  nameg  to-tableau? CGRG@:E     hh   H  ] $  C"  $	$  	
$  456CC$  %	$  45$  	6C""  @      g  
start-slot
		f g  	card-list		f g  end-slot			f  g  filenamef  
lady-jane.scm
 
	 		 		 		 		 		# 	
	& 	$	- 		1 		5 		9 		= 		B 		F 	
	G 		O 		S 	
	X 	"	\ 	 		f	  g  nameg  
droppable? CHRH'>IJ       hP  b  ]4 5$ <"  	$  	
$  ~ $   	$  4	5"  "  $  "  < 	$  2 	
$  %4 5$  "  4 >  "  G  "   "   $  
 6CCC$  	$   	$  ) 	
$  4 5$  "  4 5"  "  $  "  , $  # 	$  4	>  "  G  "   "   $  45$  
 6CC""C Z      g  
start-slot
	O g  	card-list	O g  end-slot		O g  t		I  g  t	 )  g  filenamef  
lady-jane.scm
 
	 		 		 		 		# 		' 	
	+ 		/ 		4 		8 		9 		I 		[ 		_ 		d 		h 		i 	 	s 		x 	  	
  	  	  	  	  	  	
  	  	  	  	  	   	  	  	  	 	 	 	 	- 	
. 	7 	
A 	 -	O	  g  nameg  button-released CKR:;%*LI hh   I  ] 
$  W44 55	$  4
5$  6 C44 55$  4
5$  4
5$  6 CCCC     A      g  slot-id
		c  g  filenamef  
lady-jane.scm
 
	 		
 		 		 		 		 	
	 		 		# 	(	% 		) 	
	- 		0 		3 		; 		= 	
	A 		B 		G 	(	I 		M 	
	N 		W 	
	[ 	 		c  g  nameg  button-clicked CMRENO  h0      ]	$  C4 5$   6 6            g  card
		+ g  slot-id		+  g  filenamef  
lady-jane.scm
 
	 			 		 			 		" 			) 	$	+ 		 			+	  g  nameg  move-to-foundations? COR>?)OP'I   h     ]4 5$  "  0 	$  	 	"  $  "  
44 55$  C44 5	5$  Q4 5$  D45$  84 5$  C 	$  C 	$  C 6CCC          g  slot-id
	  g  t			I g  t		)	F g  t	}  g  t   g  t    g  filenamef  
lady-jane.scm
 
	 	
		 		 		 	
	$ 		) 		7 		: 		B 		C 	
	M 		P 		S 	!	] 		a 		b 		l 		m 		v 		w 		} 	  	  	  	  	  	 	   g  nameg  button-double-clicked CQRRS        h   x   ] 45 $  C6        p       g  filenamef  
lady-jane.scm
 
	 		 		 	 		
  g  nameg  game-continuable CTR:;     hX      ] 44	55	
$  :44	55	
$  %44	55	
$  44	55	
CCCC              g  filenamef  
lady-jane.scm
 
	 	
	 		 	
	 		 		 	
	 		! 	
	$ 		( 		) 	
	, 		4 	
	7 		; 		< 	
	? 		G 	
	J 	 		Q
  g  nameg  game-won CRR:;1U h(      ] 44
55$  
45 CC              g  filenamef  
lady-jane.scm
 
	 	
	 		
 	
	 		 		 		 		 		 	 		!
  g  nameg  	dealable? CVRE)WX  h8      ]	$  $44 55$  	 6 6C              g  slot1
		1 g  slot2		1  g  filenamef  
lady-jane.scm
 
	 		 		 		 		 		 		& 		- 	%	/ 	 		1	  g  nameg  check-a-foundation CXRY>?)X        hh   5  ]	 	$  C 	$  	64 5$  "  
44 55$   64 	5$  C 6  -      g  slot-id
		f g  t	#	@ g  t	T	f  g  filenamef  
lady-jane.scm
 
	 			 		 			 		 			 	
	# 			1 		4 		< 		= 	
	D 		I 		K 			L 	
	T 			d 	#	f 	
 		f  g  nameg  check-to-foundations CYREZ        h0      ]
	$  4 5$  C 6C             g  card
		* g  slot2		* g  t			(  g  filenamef  
lady-jane.scm

						
			&	$	(	
 		*	  g  nameg  check-a-foundation2 CZR:[  h8      ]4 5$  C &   C4 5	$  C 6        g  	card-list
		7 g  card		7  g  filenamef  
lady-jane.scm

			
							
							
	
		(
		,
	
	-		3		7	 		7	  g  nameg  stripped C[R:?F(CDZ\);[W 
    h  ,  ]545
$  "  	45$  C454 5&  "  ?454 5$  "  45$  4 5"  $ n45$  " 4545$  "  $  "  45$  H4545$  "   45$  45"  "  $  "  4	5$  "  f44	55		$  "  B44
55

$  "  444
555
	$  %$  C44
55456$  C 6$  C 6      $      g  card
	
 g  slot1	
 g  	card-list		
 g  slot2		
 g  	imbedded?		
 g  t			$ g  t		S  g  t	  g  t	  g  t	  g  t	 g  t	4 g  t		U g  t	
w  g  filenamef  
lady-jane.scm

				
								 		!	
	(		+		0	!	2		3		=			C		H	%	J		K		L		S		S		a		f	%	h		k		o		p		y	 	 	 	 	
 	 	  	 	 	  	 	 	
 !	 !	) !	 !	 "	( "	3 "	( "	# #	# #	. #	# "	  "	 $	( $	3 $	( $	%$	 &	(&	3&	(&	%!		
*(	/(	'4(	4	
B)	E)	-P+	-U)	U	
c.	h.	-l0	-w.	w	
3	3	-5	-5	76	75	-3			9	
;	*;	2;	*;	%;	F;	";	<	
?	-=		C	2
C	 e	
	  g  nameg  check-a-tableau-with-pile C\RF)](CDW       h     ]
44 554455&  `44 554455$  "  '44 55$  4455"  $  	 6CC      g  r-slot
	  g  t-slot	  g  t		8	o  g  filenamef  
lady-jane.scm
E
	F		F		F		G		G		G		F		H		"H	"	*H		+H		,I		/I		7I		8H		8H		FJ		IJ	"	QJ		TJ		XJ		YL		\L	"	dL		gL		sF		|N	 	 	  g  nameg  check-a-tableau C^R_>?)\;^ h   Q  ] 	$  C 	$  		6	
$  "  $4 5$  "  
44 55$  	 	6 $  "  4 	$  * 	
$  44 5 455"  "  $  4 5 456 $  "  <45$  "  , 	$  "   	$  
4 5"  $   6 6I      g  slot1
	  g  slot2	  g  t		#	W g  t		7	T g  t	    g  filenamef  
lady-jane.scm
Q
	R			R		T			R		U			#V	
	#V			1W	
	7V			EX		HX		PX		QX	
	[R		`Y		dY			iZ		mZ			w[		{Z		 \	 Z		 ]	 ]	) _	) ]	 R	 b	$ d	$ b		 g	 g		 h	 g		 i	 i	 j	 g		 k	R	l		m	% m	 -	 	  g  nameg  check-to-tableau? C_R?`    h       ]4 5$   6 C             g  	card-list
		  g  filenamef  
lady-jane.scm
o
	p		p		p		p		r		r		q	 			  g  nameg  get-top-visible-card C`R?a     h       ]4 5$  
 6C           g  	card-list
		 g  acc		  g  filenamef  
lady-jane.scm
t
	u		u		u		u		w		w	*	w	 				  g  nameg  visible-card-count CaRb>?)@;(`
CDWac    h  H  ]	 	$  C 	$  	64 5$  "  44 55$   	
$  t 	$  f444 555$  "  G444 555	$  "  "444 555
$  		"  "  "  "  $   4
4 554564 5$  "  u 	$  "   	$  V44 55$  A44 55	$  "  44 55
$  		"  "  "  $   456 6     @      g  slot
	{ g  t	~  g  t  g  t+X  g  filenamef  
lady-jane.scm
y
	z			z		|			z		}			~		'~			-		0		8		<~			A		E~			J		N~			O		R	%	U	.	]	%	^	 	`		d~			j		m	 	p	6	x	 	z		}		~		~	 	 	% 	; 	% 	 	 	 	 z	 	 	- 	 	A 		 	 		 	 											 '	*	+	+	9	<	%D	G	K	P	fz	l	t		y	{	 I	{  g  nameg  find-high-value CbR>b     h   E  ]04	5  $  "  z4	5$  "  c4	5$  "  L4		5$  "  54	
5$  "  4	5$  "  4	5 $  
6C  =      g  t
		  g  t	  g  t		1  g  t		E  g  t		Y  g  t		m   g  filenamef  
lady-jane.scm

		
					
			+	
	1		?	
	E		S	
	Y		g	
	m		{	
 	 	 	 
  g  nameg  empty-tableau? CdRY_dV1e        hX      ]4
5  $   C4
	5  $   C45   $   C45   $   C
45 C             g  t
		R g  t
		R g  t
	+	R g  t
	;	R  g  filenamef  
lady-jane.scm

									'		+		7		;		H		L		N		Q	 		R
  g  nameg  get-hint CSRh   X   ] C    P       g  filenamef  
lady-jane.scm

 		
  g  nameg  get-options CfR   h   p   ]C    h       g  options
		  g  filenamef  
lady-jane.scm

 		  g  nameg  
apply-options CgR   h   T   ] C    L       g  filenamef  
lady-jane.scm

 		
  g  nameg  timeout ChR4iiji>  "  G  ki+iAiKiMiQiTiRiSifigihiHi6           g  filenamef  
lady-jane.scm		
		
	!	
	%	
	'			*	
	,			/	
	1			4	
	
	Z	d
6	i
	w

z	}
u 
 
 
 
 
 
  
 
; 
 " 
!J 
# 
$
%_
,
.E
2Q
3so
4rt
9ky
;h
<
=K
=
>?
>@
>
 +	>
   C6 